==> generator-ng-poly-0.12.2.tgz: package/generators/utils/app.js <==
'use strict';

var _getYoRcPath = require('get-yo-rc-path');

var _getYoRcPath2 = _interopRequireDefault(_getYoRcPath);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _removeTrailingSlash = require('remove-trailing-slash');

var _removeTrailingSlash2 = _interopRequireDefault(_removeTrailingSlash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Return JSON contents of file name from root
 * @param {String} fileName - name of file to read
 * @returns {Promise<Object>} - file contents
 */
/* eslint-disable space-before-function-paren */
function getFileFromRoot(fileName) {
  return regeneratorRuntime.async(function getFileFromRoot$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.t0 = _path2.default;
          _context.next = 3;
          return regeneratorRuntime.awrap(_getYoRcPath2.default.dir());

        case 3:
          _context.t1 = _context.sent;
          _context.t2 = fileName;
          _context.t3 = _context.t0.join.call(_context.t0, _context.t1, _context.t2);
          return _context.abrupt('return', require(_context.t3));

        case 7:
        case 'end':
          return _context.stop();
      }
    }
  }, null, this);
}

/**
 * Return build config
 * @returns {Promise<Object>} - build config
 */
function getBuildConfig() {
  return getFileFromRoot('build.config.js');
}

module.exports = {
  getFileFromRoot: getFileFromRoot,

  /**
   * Gets the appDir from the root build.config.js without trailing / or \
   * @return {Promise<String>} - app directory path
   */
  getAppDir: function getAppDir() {
    return regeneratorRuntime.async(function getAppDir$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return regeneratorRuntime.awrap(getBuildConfig());

          case 2:
            _context2.t0 = _context2.sent.appDir;
            return _context2.abrupt('return', (0, _removeTrailingSlash2.default)(_context2.t0));

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, null, this);
  },


  /**
   * Gets the unitTestDir from the root build.config.js
   * @return {Promise<String>} - unit test directory path
   */
  getUnitTestDir: function getUnitTestDir() {
    return regeneratorRuntime.async(function getUnitTestDir$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return regeneratorRuntime.awrap(getBuildConfig());

          case 2:
            return _context3.abrupt('return', _context3.sent.unitTestDir);

          case 3:
          case 'end':
            return _context3.stop();
        }
      }
    }, null, this);
  }
};

==> generator-ng-poly-0.13.0.tgz: package/generators/utils/app.js <==
'use strict';

var _getYoRcPath = require('get-yo-rc-path');

var _getYoRcPath2 = _interopRequireDefault(_getYoRcPath);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _removeTrailingSlash = require('remove-trailing-slash');

var _removeTrailingSlash2 = _interopRequireDefault(_removeTrailingSlash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Return JSON contents of file name from root
 * @param {String} fileName - name of file to read
 * @returns {Promise<Object>} - file contents
 */
/* eslint-disable space-before-function-paren */
var getFileFromRoot = function _callee(fileName) {
  return regeneratorRuntime.async(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.t0 = _path2.default;
          _context.next = 3;
          return regeneratorRuntime.awrap(_getYoRcPath2.default.dir());

        case 3:
          _context.t1 = _context.sent;
          _context.t2 = fileName;
          _context.t3 = _context.t0.join.call(_context.t0, _context.t1, _context.t2);
          return _context.abrupt('return', require(_context.t3));

        case 7:
        case 'end':
          return _context.stop();
      }
    }
  }, null, undefined);
};
/* eslint-enable global-require */

/**
 * Return build config
 * @returns {Promise<Object>} - build config
 */
var getBuildConfig = function getBuildConfig() {
  return getFileFromRoot('build.config.js');
};

module.exports = {
  getFileFromRoot: getFileFromRoot,

  /**
   * Gets the appDir from the root build.config.js without trailing / or \
   * @return {Promise<String>} - app directory path
   */
  getAppDir: function getAppDir() {
    return regeneratorRuntime.async(function getAppDir$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return regeneratorRuntime.awrap(getBuildConfig());

          case 2:
            _context2.t0 = _context2.sent.appDir;
            return _context2.abrupt('return', (0, _removeTrailingSlash2.default)(_context2.t0));

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, null, this);
  },


  /**
   * Gets the unitTestDir from the root build.config.js
   * @return {Promise<String>} - unit test directory path
   */
  getUnitTestDir: function getUnitTestDir() {
    return regeneratorRuntime.async(function getUnitTestDir$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return regeneratorRuntime.awrap(getBuildConfig());

          case 2:
            return _context3.abrupt('return', _context3.sent.unitTestDir);

          case 3:
          case 'end':
            return _context3.stop();
        }
      }
    }, null, this);
  }
};
